function plotDecisionBoundary(theta, X, y, degree)
%PLOTDECISIONBOUNDARY Plots the data points X and y into a new figure with
%the decision boundary defined by theta

% Plot Data
X1 = X(:,2:3);
figure(1);
plot( X1(y == 1, 1) , X1(y == 1, 2) , 'k+' , 'LineWidth' , 2 , 'MarkerSize' , 7 );
hold on
plot( X1(y == 0, 1) , X1(y == 0, 2) , 'ko' , 'MarkerFaceColor' , 'y' , 'MarkerSize' , 7 );
hold on

if size(X, 2) <= 3
    % Only need 2 points to define a line, so choose two endpoints
    plot_x = [min(X(:,2))-2,  max(X(:,2))+2];
    % Calculate the decision boundary line
    plot_y = (-1./theta(3)).*(theta(2).*plot_x + theta(1));
    % Plot, and adjust axes for better viewing
    plot(plot_x, plot_y)
    % Legend, specific for the exercise
    legend('Class 1', 'Class 0', 'Logistic Regressions Decision Boundary')
    axis([0, 10, 0, 10])
else
    % Here is the grid range
    u = linspace(0, 10, 100);
    v = linspace(0, 10, 100);
    z = zeros(length(u), length(v));
    % Evaluate z = theta*x over the grid
    for i = 1:length(u)
        for j = 1:length(v)
            z(i,j) = PolyFeature(u(i), v(j), degree)*theta;
        end
    end
    z = z'; % important to transpose z before calling contour
    % Plot z = 0
    % Notice you need to specify the range [0, 0]
    contour(u, v, z,[0,0], 'LineWidth', 2 )
end
end
